/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Response, Request, BaseApiCore, constructHeaders, constructUrl, executeHttpCall } from '@managed-api/commons-core';
import { errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
;
export class GoogleSheetsApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Spreadsheet = new SpreadsheetGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Spreadsheet);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options) !== null && _a !== void 0 ? _a : {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Spreadsheet) {
        this.Spreadsheet = Spreadsheet;
    }
    /**
     * Creates a spreadsheet, returning the newly created spreadsheet.
     * Alternative usage: Spreadsheet.createSpreadsheet
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets/create
     * @param options Request options.
     */
    async createSpreadsheet(options) {
        return this.Spreadsheet.createSpreadsheet(options);
    }
    /**
     * Returns the spreadsheet at the given ID. The caller must specify the spreadsheet ID. By default, data within grids will not be returned. You can include grid data one of two ways:
     ** Specify a field mask listing your desired fields using the fields URL parameter in HTTP
     ** Set the includeGridData URL parameter to true. If a field mask is set, the includeGridData parameter is ignored
     *
     * For large spreadsheets, it is recommended to retrieve only the specific fields of the spreadsheet that you want.
     * To retrieve only subsets of the spreadsheet, use the ranges URL parameter. Multiple ranges can be specified. Limiting the range will return only the portions of the spreadsheet that intersect the requested ranges. Ranges are specified using A1 notation.
     * Alternative usage: Spreadsheet.getSpreadsheet
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets/get
     * @param options Request options.
     */
    async getSpreadsheet(options) {
        return this.Spreadsheet.getSpreadsheet(options);
    }
    /**
     * Copies a single sheet from a spreadsheet to another spreadsheet. Returns the properties of the newly created sheet.
     * Alternative usage: Spreadsheet.Sheet.copySheet
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.sheets/copyTo
     * @param options Request options.
     */
    async copySpreadsheetSheet(options) {
        return this.Spreadsheet.Sheet.copySheet(options);
    }
    /**
     * Appends values to a spreadsheet. The input range is used to search for existing data and find a "table" within that range. Values will be appended to the next row of the table, starting with the first column of the table. See the guide and sample code for specific details of how tables are detected and data is appended.
     * The caller must specify the spreadsheet ID, range, and a valueInputOption. The valueInputOption only controls how the input data will be added to the sheet (column-wise or row-wise), it does not influence what cell the data starts being written to.
     * Alternative usage: Spreadsheet.Value.appendValuesInRange
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/append
     * @param options Request options.
     */
    async appendSpreadsheetValuesInRange(options) {
        return this.Spreadsheet.Value.appendValuesInRange(options);
    }
    /**
     * Clears values from a spreadsheet. The caller must specify the spreadsheet ID and range. Only values are cleared -- all other properties of the cell (such as formatting, data validation, etc..) are kept.
     * Alternative usage: Spreadsheet.Value.clearValuesInRange
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/clear
     * @param options Request options.
     */
    async clearSpreadsheetValuesInRange(options) {
        return this.Spreadsheet.Value.clearValuesInRange(options);
    }
    /**
     * Returns a range of values from a spreadsheet. The caller must specify the spreadsheet ID and a range.
     * Alternative usage: Spreadsheet.Value.getValuesInRange
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/get
     * @param options Request options.
     */
    async getSpreadsheetValuesInRange(options) {
        return this.Spreadsheet.Value.getValuesInRange(options);
    }
    /**
     * Sets values in a range of a spreadsheet. The caller must specify the spreadsheet ID, range, and a valueInputOption.
     * Alternative usage: Spreadsheet.Value.setValuesInRange
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/update
     * @param options Request options.
     */
    async setSpreadsheetValuesInRange(options) {
        return this.Spreadsheet.Value.setValuesInRange(options);
    }
}
class SpreadsheetGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Sheet = new SpreadsheetSheetGroup(implementation, this.getGlobalErrorStrategy);
        this.Value = new SpreadsheetValueGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Creates a spreadsheet, returning the newly created spreadsheet.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets/create
     * @param options Request options.
     */
    async createSpreadsheet(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/v4/spreadsheets', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the spreadsheet at the given ID. The caller must specify the spreadsheet ID. By default, data within grids will not be returned. You can include grid data one of two ways:
     ** Specify a field mask listing your desired fields using the fields URL parameter in HTTP
     ** Set the includeGridData URL parameter to true. If a field mask is set, the includeGridData parameter is ignored
     *
     * For large spreadsheets, it is recommended to retrieve only the specific fields of the spreadsheet that you want.
     * To retrieve only subsets of the spreadsheet, use the ranges URL parameter. Multiple ranges can be specified. Limiting the range will return only the portions of the spreadsheet that intersect the requested ranges. Ranges are specified using A1 notation.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets/get
     * @param options Request options.
     */
    async getSpreadsheet(options) {
        const { spreadsheetId, ranges, includeGridData, headers, errorStrategy } = options;
        const queryParams = { ranges, includeGridData };
        const request = new Request('GET', constructUrl(`/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpreadsheetSheetGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Copies a single sheet from a spreadsheet to another spreadsheet. Returns the properties of the newly created sheet.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.sheets/copyTo
     * @param options Request options.
     */
    async copySheet(options) {
        const { spreadsheetId, sheetId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}/sheets/${encodeURIComponent(sheetId)}:copyTo`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class SpreadsheetValueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Appends values to a spreadsheet. The input range is used to search for existing data and find a "table" within that range. Values will be appended to the next row of the table, starting with the first column of the table. See the guide and sample code for specific details of how tables are detected and data is appended.
     * The caller must specify the spreadsheet ID, range, and a valueInputOption. The valueInputOption only controls how the input data will be added to the sheet (column-wise or row-wise), it does not influence what cell the data starts being written to.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/append
     * @param options Request options.
     */
    async appendValuesInRange(options) {
        const { spreadsheetId, range, valueInputOption, insertDataOption, includeValuesInResponse, responseValueRenderOption, responseDateTimeRenderOption, body, headers, errorStrategy } = options;
        const queryParams = { includeValuesInResponse, insertDataOption, responseDateTimeRenderOption, responseValueRenderOption, valueInputOption };
        const request = new Request('POST', constructUrl(`/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}/values/${encodeURIComponent(range)}:append`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Clears values from a spreadsheet. The caller must specify the spreadsheet ID and range. Only values are cleared -- all other properties of the cell (such as formatting, data validation, etc..) are kept.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/clear
     * @param options Request options.
     */
    async clearValuesInRange(options) {
        const { spreadsheetId, range, headers, errorStrategy } = options;
        const request = new Request('POST', `/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}/values/${encodeURIComponent(range)}:clear`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a range of values from a spreadsheet. The caller must specify the spreadsheet ID and a range.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/get
     * @param options Request options.
     */
    async getValuesInRange(options) {
        const { spreadsheetId, range, majorDimension, valueRenderOption, dateTimeRenderOption, headers, errorStrategy } = options;
        const queryParams = { majorDimension, valueRenderOption, dateTimeRenderOption };
        const request = new Request('GET', constructUrl(`/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}/values/${encodeURIComponent(range)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Sets values in a range of a spreadsheet. The caller must specify the spreadsheet ID, range, and a valueInputOption.
     * Documentation: https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/update
     * @param options Request options.
     */
    async setValuesInRange(options) {
        const { spreadsheetId, range, valueInputOption, includeValuesInResponse, responseValueRenderOption, responseDateTimeRenderOption, body, headers, errorStrategy } = options;
        const queryParams = { valueInputOption, includeValuesInResponse, responseValueRenderOption, responseDateTimeRenderOption };
        const request = new Request('PUT', constructUrl(`/v4/spreadsheets/${encodeURIComponent(spreadsheetId)}/values/${encodeURIComponent(range)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
