/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { AppendValuesInRangeResponse } from '../../definitions/AppendValuesInRangeResponse';
import { ClearValuesInRangeResponse } from '../../definitions/ClearValuesInRangeResponse';
import { UpdateValuesResponse } from '../../definitions/UpdateValuesResponse';
import { ValueRange } from '../../definitions/ValueRange';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface AppendValuesInRangeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the spreadsheet to update.
     */
    spreadsheetId: string;
    /**
     * The A1 notation of a range to search for a logical table of data. Values are appended after the last row of the table.
     */
    range: string;
    /**
     * How the input data should be interpreted.
     ** RAW - The values the user has entered will not be parsed and will be stored as-is.
     ** USER_ENTERED - The values will be parsed as if the user typed them into the UI. Numbers will stay as numbers, but strings may be converted to numbers, dates, etc. following the same rules that are applied when entering text into a cell via the Google Sheets UI.
     */
    valueInputOption: 'RAW' | 'USER_ENTERED';
    /**
     * How the input data should be inserted.
     ** OVERWRITE - The new data overwrites existing data in the areas it is written. (Note: adding data to the end of the sheet will still insert new rows or columns so the data can be written.)
     ** INSERT_ROWS - Rows are inserted for the new data.
     */
    insertDataOption?: 'OVERWRITE' | 'INSERT_ROWS';
    /**
     * Determines if the update response should include the values of the cells that were appended. By default, responses do not include the updated values.
     */
    includeValuesInResponse?: boolean;
    /**
     * Determines how values in the response should be rendered. The default render option is ValueRenderOption.FORMATTED_VALUE.
     ** FORMATTED_VALUE - Values will be calculated & formatted in the reply according to the cell's formatting. Formatting is based on the spreadsheet's locale, not the requesting user's locale. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "$1.23".
     ** UNFORMATTED_VALUE - Values will be calculated, but not formatted in the reply. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return the number 1.23.
     ** FORMULA - Values will not be calculated. The reply will include the formulas. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "=A1".
     */
    responseValueRenderOption?: 'FORMATTED_VALUE' | 'UNFORMATTED_VALUE' | 'FORMULA';
    /**
     * Determines how dates, times, and durations in the response should be rendered. This is ignored if responseValueRenderOption is FORMATTED_VALUE. The default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].
     ** SERIAL_NUMBER - Instructs date, time, datetime, and duration fields to be output as doubles in "serial number" format, as popularized by Lotus 1-2-3. The whole number portion of the value (left of the decimal) counts the days since December 30th 1899. The fractional portion (right of the decimal) counts the time as a fraction of the day. For example, January 1st 1900 at noon would be 2.5, 2 because it's 2 days after December 30st 1899, and .5 because noon is half a day. February 1st 1900 at 3pm would be 33.625. This correctly treats the year 1900 as not a leap year.
     ** FORMATTED_STRING - Instructs date, time, datetime, and duration fields to be output as strings in their given number format (which is dependent on the spreadsheet locale).
     */
    responseDateTimeRenderOption?: 'SERIAL_NUMBER' | 'FORMATTED_STRING';
    body: {
        /**
        * The range the values cover, in A1 notation. For output, this range indicates the entire requested range, even though the values will exclude trailing rows and columns. When appending values, this field represents the range to search for a table, after which values will be appended.
        */
        range?: string;
        /**
         * The major dimension of the values.
         *
         * For output, if the spreadsheet data is: A1=1,B1=2,A2=3,B2=4, then requesting range=A1:B2,majorDimension=ROWS will return [[1,2],[3,4]], whereas requesting range=A1:B2,majorDimension=COLUMNS will return [[1,3],[2,4]].
         *
         * For input, with range=A1:B2,majorDimension=ROWS then [[1,2],[3,4]] will set A1=1,B1=2,A2=3,B2=4. With range=A1:B2,majorDimension=COLUMNS then [[1,2],[3,4]] will set A1=1,B1=3,A2=2,B2=4.
         *
         * When writing, if this field is not set, it defaults to ROWS.
         ** ROWS - Operates on the rows of a sheet.
         ** COLUMNS - Operates on the columns of a sheet.
         */
        majorDimension?: 'ROWS' | 'COLUMNS';
        /**
         * The data that was read or to be written. This is an array of arrays, the outer array representing all the data and each inner array representing a major dimension. Each item in the inner array corresponds with one cell.
         *
         * For output, empty trailing rows and columns will not be included.
         *
         * For input, supported value types are: bool, string, and double. Null values will be skipped. To set a cell to an empty value, set the string value to an empty string.
         */
        values: any[][];
    };
}
export interface AppendValuesInRangeResponseOK extends AppendValuesInRangeResponse {
}
export interface AppendValuesInRangeResponseError extends CommonError {
}
export interface ClearValuesInRangeRequest extends HeadersOption, ErrorStrategyOption {
    /**
    * The ID of the spreadsheet to update.
    */
    spreadsheetId: string;
    /**
     * The A1 notation or R1C1 notation of the values to clear.
     */
    range: string;
}
export interface ClearValuesInRangeResponseOK extends ClearValuesInRangeResponse {
}
export interface ClearValuesInRangeResponseError extends CommonError {
}
export interface GetValuesInRangeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the spreadsheet to retrieve data from.
     */
    spreadsheetId: string;
    /**
     * The A1 notation or R1C1 notation of the range to retrieve values from.
     */
    range: string;
    /**
     * The major dimension that results should use.
     *
     * For example, if the spreadsheet data is: A1=1,B1=2,A2=3,B2=4, then requesting range=A1:B2,majorDimension=ROWS returns [[1,2],[3,4]], whereas requesting range=A1:B2,majorDimension=COLUMNS returns [[1,3],[2,4]].
     ** ROWS - Operates on the rows of a sheet.
     ** COLUMNS - Operates on the columns of a sheet.
     */
    majorDimension?: 'ROWS' | 'COLUMNS';
    /**
     * How values should be represented in the output. The default render option is ValueRenderOption.FORMATTED_VALUE.
     ** FORMATTED_VALUE - Values will be calculated & formatted in the reply according to the cell's formatting. Formatting is based on the spreadsheet's locale, not the requesting user's locale. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "$1.23".
     ** UNFORMATTED_VALUE - Values will be calculated, but not formatted in the reply. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return the number 1.23.
     ** FORMULA - Values will not be calculated. The reply will include the formulas. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "=A1".
     */
    valueRenderOption?: 'FORMATTED_VALUE' | 'UNFORMATTED_VALUE' | 'FORMULA';
    /**
     * How dates, times, and durations should be represented in the output. This is ignored if valueRenderOption is FORMATTED_VALUE. The default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].
     ** SERIAL_NUMBER - Instructs date, time, datetime, and duration fields to be output as doubles in "serial number" format, as popularized by Lotus 1-2-3. The whole number portion of the value (left of the decimal) counts the days since December 30th 1899. The fractional portion (right of the decimal) counts the time as a fraction of the day. For example, January 1st 1900 at noon would be 2.5, 2 because it's 2 days after December 30st 1899, and .5 because noon is half a day. February 1st 1900 at 3pm would be 33.625. This correctly treats the year 1900 as not a leap year.
     ** FORMATTED_STRING - Instructs date, time, datetime, and duration fields to be output as strings in their given number format (which is dependent on the spreadsheet locale).
     */
    dateTimeRenderOption?: 'SERIAL_NUMBER' | 'FORMATTED_STRING';
}
export interface GetValuesInRangeResponseOK extends ValueRange {
}
export interface GetValuesInRangeResponseError extends CommonError {
}
export interface SetValuesInRangeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the spreadsheet to update.
     */
    spreadsheetId: string;
    /**
     * The A1 notation of the values to update.
     */
    range: string;
    /**
     * How the input data should be interpreted.
     ** RAW - The values the user has entered will not be parsed and will be stored as-is.
     ** USER_ENTERED - The values will be parsed as if the user typed them into the UI. Numbers will stay as numbers, but strings may be converted to numbers, dates, etc. following the same rules that are applied when entering text into a cell via the Google Sheets UI.
     */
    valueInputOption: 'RAW' | 'USER_ENTERED';
    /**
     * Determines if the update response should include the values of the cells that were updated. By default, responses do not include the updated values. If the range to write was larger than the range actually written, the response includes all values in the requested range (excluding trailing empty rows and columns).
     */
    includeValuesInResponse?: boolean;
    /**
     * Determines how values in the response should be rendered. The default render option is ValueRenderOption.FORMATTED_VALUE.
     ** FORMATTED_VALUE - Values will be calculated & formatted in the reply according to the cell's formatting. Formatting is based on the spreadsheet's locale, not the requesting user's locale. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "$1.23".
     ** UNFORMATTED_VALUE - Values will be calculated, but not formatted in the reply. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return the number 1.23.
     ** FORMULA - Values will not be calculated. The reply will include the formulas. For example, if A1 is 1.23 and A2 is =A1 and formatted as currency, then A2 would return "=A1".
     */
    responseValueRenderOption?: 'FORMATTED_VALUE' | 'UNFORMATTED_VALUE' | 'FORMULA';
    /**
     * Determines how dates, times, and durations in the response should be rendered. This is ignored if responseValueRenderOption is FORMATTED_VALUE. The default dateTime render option is DateTimeRenderOption.SERIAL_NUMBER.
     ** SERIAL_NUMBER - Instructs date, time, datetime, and duration fields to be output as doubles in "serial number" format, as popularized by Lotus 1-2-3. The whole number portion of the value (left of the decimal) counts the days since December 30th 1899. The fractional portion (right of the decimal) counts the time as a fraction of the day. For example, January 1st 1900 at noon would be 2.5, 2 because it's 2 days after December 30st 1899, and .5 because noon is half a day. February 1st 1900 at 3pm would be 33.625. This correctly treats the year 1900 as not a leap year.
     ** FORMATTED_STRING - Instructs date, time, datetime, and duration fields to be output as strings in their given number format (which is dependent on the spreadsheet locale).
     */
    responseDateTimeRenderOption?: 'SERIAL_NUMBER' | 'FORMATTED_STRING';
    body: ValueRange;
}
export interface SetValuesInRangeResponseOK extends UpdateValuesResponse {
}
export interface SetValuesInRangeResponseError extends CommonError {
}
//# sourceMappingURL=value.d.ts.map